@@ -1,6 +1,4 @@
 from pqr.core.allocation import *
-from pqr.core.backtest import *
 from pqr.core.benchmark import *
-from pqr.core.picking import *
+from pqr.core.portfolio import *
 from pqr.core.returns import *
-from pqr.core.transforms import *
